"""
Fastgame v1.0.0
>>> import fastgame

Fastgame是一个帮助你快速构建游戏或简单的GUI界面的python第三方库。
内部封装pygame2复杂的API。

作者: stripe-python
版本: 1.1.0
"""

import os
try:
    os.environ['PYGAME_HIDE_SUPPORT_PROMPT'] = 'fastgame'  # 隐藏pygame欢迎信息
except AttributeError:  # pep8
    pass

from fastgame.version import version
from fastgame.api import *

from pygame.locals import *

games = []  # 游戏对象队列
name = 'fastgame'
__version__ = version



from setuptools import setup, find_packages

with open('README.md', 'r', encoding='utf-8') as f:
    long_description = f.read()

setup(
    name='fastgame',
    author_email='13513519246@139.com',
    author='stripe-python',
    maintainer='stripe-python',
    maintainer_email='13513519246@139.com',
    py_modules=find_packages(),
    version='1.1.0',
    description='Fastgame是一个帮助你快速构建游戏或简单的GUI界面的python第三方库。',
    long_description=long_description,
    long_description_content_type='text/markdown',
    classifiers=[
        'Programming Language :: Python :: 3',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
    ],
    install_requires=['pygame>=2.1.0', 'arrow', 'opencv-python', 'tqdm', 'pillow'],
    python_requires='>=3.6',
)
